@@ -31,17 +31,18 @@ class Spinner:
         )
         self.delay = delay
         self.message = message
-        self._running = False
+        self._stop_event = threading.Event()
         self._thread = None
 
     def _spin(self):
         """The actual spinning loop."""
-        while self._running:
+        while not self._stop_event.is_set():
             char = next(self.spinner)
             # Write message, spinner character, and flush
             sys.stdout.write(f"{self.message} {char}")
             sys.stdout.flush()
-            time.sleep(self.delay)
+            # Wait for the delay, but wake up immediately if the event is set
+            self._stop_event.wait(self.delay)
             # Erase the line using carriage return and spaces
             sys.stdout.write("\r" + " " * (len(self.message) + 2) + "\r")
 
@@ -50,21 +51,19 @@ class Spinner:
         if self._thread is not None and self._thread.is_alive():
             return  # Already running
 
-        self._running = True
+        self._stop_event.clear()
         # Make the thread a daemon so it exits when the main program exits
         self._thread = threading.Thread(target=self._spin, daemon=True)
         self._thread.start()
 
     def stop(self):
         """Stops the spinner and cleans up the line."""
-        if not self._running:
-            return  # Already stopped
+        if self._stop_event.is_set():
+            return  # Already stopped or stopping
 
-        self._running = False
+        self._stop_event.set()
         if self._thread:
-            self._thread.join(
-                timeout=self.delay * 2
-            )  # Wait briefly for thread to finish
+            self._thread.join()  # Wait for the thread to finish completely
 
         # Clear the line completely after stopping (message + space + spinner char)
         sys.stdout.write("\r" + " " * (len(self.message) + 3) + "\r")
@@ -91,6 +90,10 @@ if __name__ == "__main__":
     try:
         # Simulate work
         time.sleep(3)
+        print("\nInterrupting task 1...")
+        # Simulate a Ctrl+C interruption
+    except KeyboardInterrupt:
+        pass # Expected
     finally:
         spinner1.stop()
     print("Task 1 finished.")
